@@ -14,13 +14,13 @@ __all__ = [
 ]
 
 __title__ = "SWUGenerator"
-__summary__ = "Generator SWU Packages for SWUpdate"
+__summary__ = "SWU Package Generator for SWUpdate"
 __uri__ = "https://github.com/sbabic/swugenerator"
 
-__version__ = "0.2"
+__version__ = "0.3"
 
 __author__ = "Stefano Babic"
-__email__ = "stefano.babic@babic.homelinux.org"
+__email__ = "stefano.babic@swupdate.org"
 
 __license__ = "GPL version 3"
-__copyright__ = f"Copyright 2022 {__author__}"
+__copyright__ = f"Copyright 2022-2024 {__author__}"
